# -*- coding: utf-8 -*-

from ..utils import *


class bloco_d(TrackedAttributesClass):
    """
    BLOCO D: DOCUMENTOS FISCAIS II - SERVIÇOS (ICMS).
    Bloco de registros dos dados relativos à emissão ou ao recebimento de documentos fiscais que acobertam as
    prestações de serviços de comunicação, transporte intermunicipal e interestadual.
    """

    class registro_D001(TrackedAttributesClass):
        """
        REGISTRO D001: ABERTURA DO BLOCO D
        Este registro deve ser gerado para abertura do Bloco D e indica se há informações sobre prestações ou
        contratações de serviços de comunicação, transporte interestadual e intermunicipal, com o devido suporte do
        correspondente documento fiscal.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D001, self).__init__()
            self.REG = 'D001'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = ''  # Indicador de movimento: 0- Bloco com dados informados; 1- Bloco sem dados informados
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_D010(TrackedAttributesClass):
        """
               REGISTRO D010: IDENTIFICAÇÃO DO ESTABELECIMENTO
            Este registro tem o objetivo de identificar o estabelecimento da pessoa jurídica a que se referem as operações e
            documentos fiscais informados neste bloco. Só devem ser escriturados no Registro D010 os estabelecimentos que
            efetivamente tenham realizado as operações especificadas no Bloco D (prestação ou contratação), relativas a serviços de
            transporte de cargas e/ou de passageiros, serviços de comunicação e de telecomunicação, mediante emissão de
            documento fiscal definido pela legislação do ICMS e do IPI, que devam ser escrituradas no Bloco D.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D010, self).__init__()
            self.REG = 'D010'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.CNPJ = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CNPJ': {'tipo': 'N', 'tamanho': 14, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'CNPJ')
            self.formato = self.get_formato()

    class registro_D100(TrackedAttributesClass):
        """
        REGISTRO D100: NOTA FISCAL DE SERVIÇO DE TRANSPORTE (CÓDIGO 07) E CONHECIMENTOS DE TRANSPORTE RODOVIÁRIO DE CARGAS (CÓDIGO 08),
        CONHECIMENTOS DE TRANSPORTE DE CARGAS AVULSO (CÓDIGO 8B), AQUAVIÁRIO DE CARGAS (CÓDIGO 09), AÉREO (CÓDIGO 10), FERROVIÁRIO DE
        CARGAS (CÓDIGO 11) E MULTIMODAL DE CARGAS (CÓDIGO 26), NOTA FISCAL DE TRANSPORTE FERROVIÁRIO DE CARGA ( CÓDIGO 27) E CONHECIMENTO DE
        TRANSPORTE ELETRÔNICO – CT-e (CÓDIGO 57).Este registro deve ser apresentado por todos os contribuintes adquirentes ou prestadores dos
        serviços que utilizem os documentos previstos para este registro.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D100, self).__init__()
            self.REG = 'D100'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'D001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_OPER = ''  # Indicador do tipo de operação: 0- Aquisição; 1-
            self.IND_EMIT = ''  # Prestação Indicador do emitente do documento fiscal: 0- Emissão própria; 1- Terceiros
            self.COD_PART = ''  # Código do participante (campo 02 do Registro 0150): - do prestador de serviço, no caso de aquisição de serviço; - do tomador do serviço, no caso de prestação de serviços.
            self.COD_MOD = ''  # Código do modelo do documento fiscal, conforme a Tabela 4.1.1
            self.COD_SIT = ''  # Código da situação do documento fiscal, conforme a Tabela 4.1.2
            self.SER = ''  # Série do documento fiscal
            self.SUB = ''  # Subsérie do documento fiscal
            self.NUM_DOC = ''  # Número do documento fiscal
            self.CHV_CTE = ''  # Chave do Conhecimento de Transporte Eletrônico
            self.DT_DOC = ''  # Data da emissão do documento fiscal
            self.DT_A_P = ''  # Data da aquisição ou da prestação do serviço
            self.TP_CT_e = ''  # Tipo de Conhecimento de Transporte Eletrônico conforme definido no Manual de Integração do CT-e
            self.CHV_CTE_REF = ''  # Chave do CT-e de referência cujos valores foram complementados (opção “1” do campo anterior) ou cujo débito foi anulado(opção “2” do campo anterior).
            self.VL_DOC = ''  # Valor total do documento fiscal
            self.VL_DESC = ''  # Valor total do desconto
            self.IND_FRT = ''  # Indicador do tipo do frete: 0- Por conta de terceiros; 1- Por conta do emitente; 2- Por conta do destinatário; 9- Sem cobrança de frete.
            self.VL_SERV = ''  # Valor total da prestação de serviço
            self.VL_BC_ICMS = ''  # Valor da base de cálculo do ICMS
            self.VL_ICMS = ''  # Valor do ICMS
            self.VL_NT = ''  # Valor não-tributado
            self.COD_INF = ''  # Código da informação complementar do documento fiscal (campo 02 do Registro 0450)
            self.COD_CTA = ''  # Código da conta analítica contábil debitada/creditada
            self.fieldnames = ('REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'COD_SIT', 
                               'SER', 'SUB', 'NUM_DOC', 'CHV_CTE', 'DT_DOC', 'DT_A_P', 'TP_CT_e', 
                               'CHV_CTE_REF', 'VL_DOC', 'VL_DESC', 'IND_FRT', 'VL_SERV', 
                               'VL_BC_ICMS', 'VL_ICMS', 'VL_NT', 'COD_INF', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_D101(TrackedAttributesClass):
        """
        REGISTRO D101: COMPLEMENTO DO DOCUMENTO DE TRANSPORTE (Códigos 07,
        08, 8B, 09, 10, 11, 26, 27 e 57) – PIS/PASEP
        Serão escrituradas neste registro as informações referentes à incidência, base de cálculo, alíquota e valor do crédito de
        PIS/Pasep, básico ou presumido, referente às operações de transporte contratadas ou subcontratadas, conforme previsto
        na legislação
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D101, self).__init__()
            self.REG = 'D101'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_NAT_FRT = ''
            self.VL_ITEM = ''  # Número sequencial do item no documento fiscal
            self.CST_PIS = ''  # Código do item (campo 02 do Registro 0200)
            self.NAT_BC_CRED = ''  # Valor do serviço
            self.VL_BC_PIS = ''  # Outros valores
            self.ALIQ_PIS = ''
            self.VL_PIS = ''
            self.COD_CTA = ''
            self.fieldnames = ('REG', 'IND_NAT_FRT', 'VL_ITEM', 'CST_PIS', 'NAT_BC_CRED', 
                               'VL_BC_PIS', 'ALIQ_PIS', 'VL_PIS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_D105(TrackedAttributesClass):
        """
            REGISTRO D105: COMPLEMENTO DO DOCUMENTO DE TRANSPORTE (Códigos 07,
            08, 8B, 09, 10, 11, 26, 27 e 57) – COFINS
            Serão escrituradas neste registro as informações referentes à incidência, base de cálculo, alíquota e valor do crédito de
            Cofins, básicos ou presumidos, referente às operações de transporte contratadas ou subcontratadas, conforme previsto
            na legislação.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D105, self).__init__()
            self.REG = 'D105'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_NAT_FRT = ''
            self.VL_ITEM = ''  # Número sequencial do item no documento fiscal
            self.CST_COFINS = ''  # Código do item (campo 02 do Registro 0200)
            self.NAT_BC_CRED = ''  # Valor do serviço
            self.VL_BC_COFINS = ''  # Outros valores
            self.ALIQ_COFINS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.fieldnames = ('REG', 'IND_NAT_FRT', 'VL_ITEM', 'CST_COFINS', 'NAT_BC_CRED',
                               'VL_BC_COFINS', 'ALIQ_COFINS', 'VL_COFINS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_D111(TrackedAttributesClass):
        """
            REGISTRO D111: PROCESSO REFERENCIADO
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D111, self).__init__()
            self.REG = 'D111'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_PROC = ''  # Número sequencial do item no documento fiscal
            self.IND_PROC = ''  # Código do item (campo 02 do Registro 0200)
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D200(TrackedAttributesClass):
        """
            REGISTRO D200: RESUMO DA ESCRITURAÇÃO DIÁRIA – PRESTAÇÃO DE SERVIÇOS DE
            TRANSPORTE - NOTA FISCAL DE SERVIÇO DE TRANSPORTE (CÓDIGO 07) E
            CONHECIMENTOS DE TRANSPORTE RODOVIÁRIO DE CARGAS (CÓDIGO 08),
            CONHECIMENTO DE TRANSPORTE DE CARGAS AVULSO (CÓDIGO 8B), AQUAVIÁRIO DE
            CARGAS (CÓDIGO 09), AÉREO (CÓDIGO 10), FERROVIÁRIO DE CARGAS (CÓDIGO 11),
            MULTIMODAL DE CARGAS (CÓDIGO 26), NOTA FISCAL DE TRANSPORTE FERROVIÁRIO
            DE CARGA (CÓDIGO 27) E CONHECIMENTO DE TRANSPORTE ELETRÔNICO – CT-e
            (CÓDIGO 57
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D200, self).__init__()
            self.REG = 'D200'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'D110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''
            self.COD_SIT = ''
            self.SER = ''
            self.SUB = ''
            self.NUM_DOC_INI = ''
            self.NUM_DOC_FIN = ''
            self.CFOP = ''
            self.DT_REF = ''
            self.VL_DOC = ''
            self.VL_DESC = ''
            self.fieldnames = ('REG', 'COD_MOD', 'COD_SIT', 'SER', 'SUB', 'NUM_DOC_INI', 
                               'NUM_DOC_FIN', 'CFOP', 'DT_REF', 'VL_DOC', 'VL_DESC')
            self.formato = self.get_formato()

    class registro_D201(TrackedAttributesClass):
        """
        REGISTRO D201: TOTALIZAÇÃO DO RESUMO DIÁRIO – PIS/PASEP
        Serão escrituradas neste registro as informações referentes à incidência, base de cálculo, alíquota e valor do PIS/Pasep,
        referente às operações de transporte consolidadas em D200.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D201, self).__init__()
            self.REG = 'D201'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'D200'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_PIS = ''
            self.VL_ITEM = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.VL_PIS = ''
            self.COD_CTA = ''
            self.fieldnames = ('REG', 'CST_PIS', 'VL_ITEM', 'VL_BC_PIS', 'ALIQ_PIS', 'VL_PIS', 
                               'COD_CTA')
            self.formato = self.get_formato()


    class registro_D205(TrackedAttributesClass):
        """
            REGISTRO D205: TOTALIZAÇÃO DO RESUMO DIÁRIO – COFINS
            Serão escrituradas neste registro as informações referentes à incidência, base de cálculo, alíquota e valor da Cofins,
            referente às operações de transporte consolidadas em D200.
            """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D205, self).__init__()
            self.REG = 'D205'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'D200'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_COFINS = ''
            self.VL_ITEM = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.fieldnames = ('REG', 'CST_COFINS', 'VL_ITEM', 'VL_BC_COFINS', 'ALIQ_COFINS', 'VL_COFINS',
                               'COD_CTA')
            self.formato = self.get_formato()            

    class registro_D130(TrackedAttributesClass):
        """
        REGISTRO D130: COMPLEMENTO DO CONHECIMENTO RODOVIÁRIO DE CARGAS (CÓDIGO 08) E DO CONHECIMENTO RODOVIÁRIO DE CARGAS AVULSO (CÓDIGO 8B).
        Este registro tem por objetivo informar o complemento do Conhecimento de Transporte Rodoviário de Cargas
        (Código 08) e Conhecimento de Transporte de Cargas Avulso (Código 8B).
        Obs. Para operações que envolvem destinos ou origens em cidades fora do Brasil, os campos
        COD_MUN_ORIG ou COD_MUN_DEST dos registros D120, D130, D140, D150, D160, D170 e D180 deverão
        ser preenchidos com o código “9999999”.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D130, self).__init__()
            self.REG = 'D130'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_PART_CONSG = ''  # Código do participante (campo 02 do Registro 0150): - consignatário, se houver
            self.COD_PART_RED = ''  # Código do participante (campo 02 do Registro 0150): - redespachado, se houver
            self.IND_FRT_RED = ''  # Indicador do tipo do frete da operação de redespacho: 0 – Sem redespacho; 1 - Por conta do emitente; 2 - Por conta do destinatário; 9 – Outros
            self.COD_MUN_ORIG = ''  # Código do município de origem do serviço, conforme a tabela IBGE(Preencher com 9999999, se Exterior)
            self.COD_MUN_DEST = ''  # Código do município de destino, conforme a tabela IBGE(Preencher com 9999999, se Exterior)
            self.VEIC_ID = ''  # Placa de identificação do veículo
            self.VL_LIQ_FRT = ''  # Valor líquido do frete
            self.VL_SEC_CAT = ''  # Soma de valores de Sec/Cat (serviços de coleta/custo adicional de transporte)
            self.VL_DESP = ''  # Soma de valores de despacho
            self.VL_PEDG = ''  # Soma dos valores de pedágio
            self.VL_OUT = ''  # Outros valores
            self.VL_FRT = ''  # Valor total do frete
            self.UF_ID = ''  # Sigla da UF da placa do veículo
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D140(TrackedAttributesClass):
        """
        REGISTRO D140: COMPLEMENTO DO CONHECIMENTO AQUAVIÁRIO DE CARGAS (CÓDIGO 09).
        Este registro tem por objetivo informar o complemento do Conhecimento de Transporte Aquaviário de Cargas
        (Código 09).
        Obs. Para operações que envolvem destinos ou origens em cidades fora do Brasil, os campos COD_MUN_ORIG
        ou COD_MUN_DEST dos registros D120, D130, D140, D150, D160, D170 e D180 deverão ser preenchidos com o
        código “9999999”.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D140, self).__init__()
            self.REG = 'D140'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D100'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.COD_PART_CONSG = ''  # Código do participante (campo 02 do Registro 0150): - consignatário, se houver
            self.COD_MUN_ORIG = ''  # Código do município de origem do serviço, conforme a tabela IBGE(Preencher com 9999999, se Exterior)
            self.COD_MUN_DEST = ''  # Código do município de destino, conforme a tabela IBGE(Preencher com 9999999, se Exterior)
            self.IND_VEIC = ''  # Indicador do tipo do veículo transportador: 0- Embarcação; 1- Empurrador/rebocador
            self.VEIC_ID = ''  # Identificação da embarcação (IRIM ou Registro CPP)
            self.IND_NAV = ''  # Indicador do tipo da navegação: 0- Interior; 1- Cabotagem
            self.VIAGEM = ''  # Número da viagem
            self.VL_FRT_LIQ = ''  # Valor líquido do frete
            self.VL_DESP_PORT = ''  # Valor das despesas portuárias
            self.VL_DESP_CAR_DESC = ''  # Valor das despesas com carga e descarga
            self.VL_OUT = ''  # Outros valores
            self.VL_FRT_BRT = ''  # Valor bruto do frete
            self.VL_FRT_MM = ''  # Valor adicional do frete para renovação da Marinha Mercante
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D150(TrackedAttributesClass):
        """
        REGISTRO D150: COMPLEMENTO DO CONHECIMENTO AÉREO (CÓDIGO 10).
        Este registro tem por objetivo informar o complemento do Conhecimento de Transporte Aéreo de Cargas (Código
        10). Obs. Para operações que envolvem destinos ou origens em cidades fora do Brasil, os campos COD_MUN_ORIG
        ou COD_MUN_DEST dos registros D120, D130, D140, D150, D160, D170 e D180 deverão ser preenchidos com o
        código “9999999”
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D150, self).__init__()
            self.REG = 'D150'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D100'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.COD_MUN_ORIG = ''
            self.COD_MUN_DEST = ''
            self.VEIC_ID = ''
            self.VIAGEM = ''
            self.IND_TFA = ''
            self.VL_PESO_TX = ''
            self.VL_TX_TERR = ''
            self.VL_TX_RED = ''
            self.VL_OUT = ''
            self.VL_TX_ADV = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D160(TrackedAttributesClass):
        """
        REGISTRO D160: CARGA TRANSPORTADA (CÓDIGO 08, 8B, 09, 10, 11, 26 e 27).
        Neste registro devem ser apresentados dados sobre o transporte da carga, objeto dos conhecimentos de transporte
        aqui especificados.
        Obs. Para operações que envolvem destinos ou origens em cidades fora do Brasil, os campos COD_MUN_ORIG
        ou COD_MUN_DEST dos registros D120, D130, D140, D150, D160, D170 e D180 deverão ser preenchidos com o
        código “9999999”.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D160, self).__init__()
            self.REG = 'D160'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.DESPACHO = ''
            self.CNPJ_CPF_REM = ''
            self.IE_REM = ''
            self.COD_MUN_ORI = ''
            self.CNPJ_CPF_DEST = ''
            self.IE_DEST = ''
            self.COD_MUN_DEST = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D161(TrackedAttributesClass):
        """
        REGISTRO D161: LOCAL DA COLETA E ENTREGA (CÓDIGO 08, 8B, 09, 10, 11 e 26).
        Este registro tem por objetivo informar o local de coleta e/ou entrega quando esse for diferente do endereço do
        remetente e/ou destinatário.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D161, self).__init__()
            self.REG = 'D161'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'D160'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_CARGA = ''
            self.CNPJ_CPF_COL = ''
            self.IE_COL = ''
            self.COD_MUN_COL = ''
            self.CNPJ_CPF_ENTG = ''
            self.IE_ENTG = ''
            self.COD_MUN_ENTG = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D162(TrackedAttributesClass):
        """
        REGISTRO D162: IDENTIFICAÇÃO DOS DOCUMENTOS FISCAIS (CÓDIGOS 08, 8B, 09, 10, 11, 26 E 27)
        Neste registro devem ser apresentados dados dos documentos fiscais que acobertam a carga transportada, objeto
        dos conhecimentos de transporte previstos no registro D160.
        Não informar este registro caso o CFOP do conhecimento de transporte seja 5359 ou 6359.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D162, self).__init__()
            self.REG = 'D162'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'D160'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''
            self.SER = ''
            self.NUM_DOC = ''
            self.DT_DOC = ''
            self.VL_DOC = ''
            self.VL_MERC = ''
            self.QTD_VOL = ''
            self.PESO_BRT = ''
            self.PESO_LIQ = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D170(TrackedAttributesClass):
        """
        REGISTRO D170: COMPLEMENTO DO CONHECIMENTO MULTIMODAL DE CARGAS (CÓDIGO 26).
        Este registro tem por objetivo informar o complemento do Conhecimento Multimodal de Cargas (Código 26).
        Obs. Para operações que envolvem destinos ou origens em cidades fora do Brasil, os campos COD_MUN_ORIG
        ou COD_MUN_DEST dos registros D120, D130, D140, D150, D160, D170 e D180 deverão ser preenchidos com o
        código “9999999”.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D170, self).__init__()
            self.REG = 'D170'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D100'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.COD_PART_CONSG = ''
            self.COD_PART_RED = ''
            self.COD_MUN_ORIG = ''
            self.COD_MUN_DEST = ''
            self.OTM = ''
            self.IND_NAT_FRT = ''
            self.VL_LIQ_FRT = ''
            self.VL_GRIS = ''
            self.VL_PDG = ''
            self.VL_OUT = ''
            self.VL_FRT = ''
            self.VEIC_ID = ''
            self.UF_ID = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D180(TrackedAttributesClass):
        """
        REGISTRO D180: MODAIS (CÓDIGO 26)
        Este registro tem por objetivo identificar todos os transportadores e seus documentos fiscais emitidos durante o
        transporte multimodal.
        Obs. Para operações que envolvem destinos ou origens em cidades fora do Brasil, os campos COD_MUN_ORIG ou
        COD_MUN_DEST dos registros D120, D130, D140, D150, D160, D170 e D180 deverão ser preenchidos com o código
        “9999999”.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D180, self).__init__()
            self.REG = 'D180'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_SEQ = ''
            self.IND_EMIT = ''
            self.CNPJ_CPF_EMIT = ''
            self.UF_EMIT = ''
            self.IE_EMIT = ''
            self.COD_MUN_ORIG = ''
            self.CNPJ_CPF_TOM = ''
            self.UF_TOM = ''
            self.IE_TOM = ''
            self.COD_MUN_DEST = ''
            self.COD_MOD = ''
            self.SER = ''
            self.SUB = ''
            self.NUM_DOC = ''
            self.DT_DOC = ''
            self.VL_DOC = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D190(TrackedAttributesClass):
        """
        REGISTRO D190: REGISTRO ANALÍTICO DOS DOCUMENTOS (CÓDIGO 07, 08, 8B, 09, 10, 11, 26, 27 e 57).
        Este registro tem por objetivo informar as Notas Fiscais de Serviço de Transporte (Código 07) e demais
        documentos elencados no título deste registro e especificados no registro D100, totalizados pelo agrupamento das
        combinações dos valores de CST, CFOP e Alíquota dos itens de cada documento.
        Obs.: Nas operações de entradas, informar o CST que constar no documento fiscal de aquisição dos serviços.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D190, self).__init__()
            self.REG = 'D190'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D100'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''
            self.CFOP = ''
            self.ALIQ_ICMS = ''
            self.VL_OPR = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.VL_RED_BC = ''
            self.COD_OBS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D300(TrackedAttributesClass):
        """
        REGISTRO D300: REGISTRO ANALÍTICO DOS BILHETES CONSOLIDADOS DE PASSAGEM RODOVIÁRIO (CÓDIGO 13), DE PASSAGEM AQUAVIÁRIO (CÓDIGO 14),
        DE PASSAGEM E NOTA DE BAGAGEM (CÓDIGO 15) E DE PASSAGEM FERROVIÁRIO (CÓDIGO 16).
        Este registro deve ser apresentado por todos os contribuintes prestadores dos serviços de transporte de passageiros
        e bagagens. A consolidação deve ser feita obedecendo à combinação CST, CFOP e Alíquota, considerando o modelo, série
        e subsérie. A numeração dos documentos cancelados deve estar inclusa em cada consolidação.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D300, self).__init__()
            self.REG = 'D300'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'D001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''
            self.SER = ''
            self.SUB = ''
            self.NUM_DOC_INI = ''
            self.NUM_DOC_FIN = ''
            self.CST_ICMS = ''
            self.CFOP = ''
            self.ALIQ_ICMS = ''
            self.DT_DOC = ''
            self.VL_OPR = ''
            self.VL_DESC = ''
            self.VL_SERV = ''
            self.VL_SEG = ''
            self.VL_OUT_DESP = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.VL_RED_BC = ''
            self.COD_OBS = ''
            self.COD_CTA = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D301(TrackedAttributesClass):
        """
        REGISTRO D301: DOCUMENTOS CANCELADOS DOS BILHETES DE PASSAGEM RODOVIÁRIO (CÓDIGO 13), DE PASSAGEM AQUAVIÁRIO (CÓDIGO 14), DE
        PASSAGEM E NOTA DE BAGAGEM (CÓDIGO 15) E DE PASSAGEM FERROVIÁRIO(CÓDIGO 16).
        Este registro tem por objetivo informar os números dos documentos fiscais cancelados no intervalo constante no
        registro pai.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D301, self).__init__()
            self.REG = 'D301'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D300'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_DOC_CANC = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D310(TrackedAttributesClass):
        """
        REGISTRO D310: COMPLEMENTO DOS BILHETES (CÓDIGO 13, 14, 15 E 16).
        Este registro tem por objetivo agrupar por município de origem os valores dos documentos fiscais resumidos no
        registro D300.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D310, self).__init__()
            self.REG = 'D310'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D300'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MUN_ORIG = ''
            self.VL_SERV = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D350(TrackedAttributesClass):
        """
        REGISTRO D350 EQUIPAMENTO ECF (CÓDIGOS 2E, 13, 14, 15 e 16).
        Este registro tem por objetivo identificar os equipamentos de ECF por todos os contribuintes que emitam Cupom
        Fiscal Bilhete de Passagem (Código 2E), Bilhete de Passagem Rodoviário (13), Bilhete de Passagem Aquaviário (14),
        Bilhete de Passagem e Nota de Bagagem (15) e Bilhete de Passagem Ferroviário (16).
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D350, self).__init__()
            self.REG = 'D350'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'D001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''
            self.ECF_MOD = ''
            self.ECF_FAB = ''
            self.ECF_CX = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D355(TrackedAttributesClass):
        """
        REGISTRO D355 REDUÇÃO Z (CÓDIGOS 2E, 13, 14, 15 e 16).
        Este registro deve ser apresentado com as informações da Redução Z de cada equipamento em funcionamento na
        data das prestações à qual se refere a redução. Este registro inclui todos os documentos ficais, totalizados na Redução Z,
        incluindo as prestações realizadas durante o período de tolerância do Equipamento ECF.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D355, self).__init__()
            self.REG = 'D355'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D350'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.DT_DOC = ''
            self.CRO = ''
            self.CRZ = ''
            self.NUM_COO_FIN = ''
            self.GT_FIN = ''
            self.VL_BRT = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D360(TrackedAttributesClass):
        """
        REGISTRO D360: PIS E COFINS TOTALIZADOS NO DIA (CÓDIGOS 2E, 13, 14, 15 e 16).
        Este registro somente deve ser apresentado para informar os valores de PIS e COFINS totalizados no dia.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D360, self).__init__()
            self.REG = 'D360'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'D355'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.VL_PIS = ''
            self.VL_COFINS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D365(TrackedAttributesClass):
        """
        REGISTRO D365: REGISTRO DOS TOTALIZADORES PARCIAIS DA REDUÇÃO Z (CÓDIGOS 2E, 13, 14, 15 e 16).
        Este registro deve ser apresentado para discriminar os valores por código de totalizador da Redução Z.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D365, self).__init__()
            self.REG = 'D365'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'D355'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_TOT_PAR = ''
            self.VLR_ACUM_TOT = ''
            self.NR_TOT = ''
            self.DESCR_NR_TOT = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D370(TrackedAttributesClass):
        """
        REGISTRO D370: COMPLEMENTO DOS DOCUMENTOS INFORMADOS (CÓDIGOS 13, 14, 15 e 16 e 2E)
        Este registro tem por objetivo agrupar por município de origem os valores dos totalizadores parciais da redução Z.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D370, self).__init__()
            self.REG = 'D370'  # Texto fixo contendo
            self.nivel_h = 5  # nível
            self.pai = 'D365'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MUN_ORIG = ''
            self.VL_SERV = ''
            self.QTD_BILH = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D390(TrackedAttributesClass):
        """
        REGISTRO D390: REGISTRO ANALÍTICO DO MOVIMENTO DIÁRIO (CÓDIGOS 13, 14, 15, 16 E 2E).
        Este registro representa a escrituração dos documentos fiscais emitidos por ECF e totalizados pela combinação de
        CST, CFOP e Alíquota.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D390, self).__init__()
            self.REG = 'D390'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'D355'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''
            self.CFOP = ''
            self.ALIQ_ICMS = ''
            self.VL_OPR = ''
            self.VL_BC_ISSQN = ''
            self.ALIQ_ISSQN = ''
            self.VL_ISSQN = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.COD_OBS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D400(TrackedAttributesClass):
        """
        REGISTRO D400: RESUMO DE MOVIMENTO DIÁRIO - RMD (CÓDIGO 18).
        Este registro tem por objetivo a apresentação dos documentos emitidos pelas agências, postos, filiais ou veículos
        de estabelecimentos que executam serviços de transporte com inscrição centralizada, quando autorizados pelo fisco
        estadual.
        Para cada registro D400, obrigatoriamente deve ser apresentado, pelo menos, um registro D420,
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D400, self).__init__()
            self.REG = 'D400'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'D001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_PART = ''
            self.COD_MOD = ''
            self.COD_SIT = ''
            self.SER = ''
            self.SUB = ''
            self.NUM_DOC = ''
            self.DT_DOC = ''
            self.VL_DOC = ''
            self.VL_DESC = ''
            self.VL_SERV = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.VL_PIS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D410(TrackedAttributesClass):
        """
        REGISTRO D410: DOCUMENTOS INFORMADOS (CÓDIGOS 13, 14, 15 E 16).
        Este registro tem por objetivo informar os documentos consolidados no Resumo de Movimento Diário (Código
        18). Neste registro, deverão ser informados os documentos Bilhete de Passagem Rodoviário (Código 13), Bilhete de
        Passagem Aquaviário (Código 14), Bilhete de Passagem Ferroviário (Código 16) e Bilhete de Passagem e Nota de
        Bagagem (Código 15), não emitidos por ECF.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D410, self).__init__()
            self.REG = 'D410'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D400'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''
            self.SER = ''
            self.SUB = ''
            self.NUM_DOC_INI = ''
            self.NUM_DOC_FIN = ''
            self.DT_DOC = ''
            self.CST_ICMS = ''
            self.CFOP = ''
            self.ALIQ_ICMS = ''
            self.VL_OPR = ''
            self.VL_DESC = ''
            self.VL_SERV = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D411(TrackedAttributesClass):
        """
        REGISTRO D411: DOCUMENTOS CANCELADOS DOS DOCUMENTOS INFORMADOS (CÓDIGO 13, 14, 15 e 16).
        Este registro tem por objetivo informar os números dos documentos fiscais cancelados.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D411, self).__init__()
            self.REG = 'D411'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'D410'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_DOC_CANC = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D420(TrackedAttributesClass):
        """
        REGISTRO D420: COMPLEMENTO DOS DOCUMENTOS INFORMADOS (CÓDIGO 13, 14, 15 e 16).
        Este registro tem por objetivo agrupar por município de origem os valores resumidos no registro D400.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D420, self).__init__()
            self.REG = 'D420'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D400'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MUN_ORIG = ''
            self.VL_SERV = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D500(TrackedAttributesClass):
        """
        REGISTRO D500: NOTA FISCAL DE SERVIÇO DE COMUNICAÇÃO (CÓDIGO 21) E
        NOTA FISCAL DE SERVIÇO DE TELECOMUNICAÇÃO (CÓDIGO 22).
        Este registro tem por objetivo apresentar as notas fiscais de serviços de comunicações. Na aquisição de serviço,
        será utilizado por todos os contribuintes; nas prestações de serviço, pelos contribuintes não enquadrados no Convênio
        ICMS 115/03. Empresas sujeitas ao disposto no Convênio ICMS 115/03 deverão utilizar este registro para informar os
        documentos emitidos nos modelos 21 e 22, nos casos não previstos no referido convênio, se houver.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D500, self).__init__()
            self.REG = 'D500'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'D001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_OPER = ''
            self.IND_EMIT = ''
            self.COD_PART = ''
            self.COD_MOD = ''
            self.COD_SIT = ''
            self.SER = ''
            self.SUB = ''
            self.NUM_DOC = ''
            self.DT_DOC = ''
            self.DT_A_P = ''
            self.VL_DOC = ''
            self.VL_DESC = ''
            self.VL_SERV = ''
            self.VL_SERV_NT = ''
            self.VL_TERC = ''
            self.VL_DA = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.COD_INF = ''
            self.VL_PIS = ''
            self.VL_COFINS = ''
            self.fieldnames = ('REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'COD_SIT',
                               'SER', 'SUB', 'NUM_DOC', 'DT_DOC', 'DT_A_P', 'VL_DOC', 'VL_DESC',
                               'VL_SERV', 'VL_SERV_NT', 'VL_TERC', 'VL_DA', 'VL_BC_ICMS', 'VL_ICMS',
                               'COD_INF', 'VL_PIS', 'VL_COFINS')
            self.formato = self.get_formato()

    class registro_D501(TrackedAttributesClass):
        """COMPLEMENTO DA OPERAÇÃO (CÓDIGOS 21 e 22) – PIS/PASEP"""
        _order = []

        def __init__(self):
            super(bloco_d.registro_D501, self).__init__()
            self.REG = 'D501'
            self.nivel_h = 4
            self.pai = 'D500'
            self.ocorrencia = 'N'
            self.CST_PIS = ''
            self.VL_ITEM = ''
            self.NAT_BC_CRED = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.VL_PIS = ''
            self.COD_CTA = ''
            self.fieldnames = ('REG', 'CST_PIS', 'VL_ITEM', 'NAT_BC_CRED', 'VL_BC_PIS', 'ALIQ_PIS',
                               'VL_PIS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_D505(TrackedAttributesClass):
        """COMPLEMENTO DA OPERAÇÃO (CÓDIGOS 21 e 22) – COFINS"""
        _order = []

        def __init__(self):
            super(bloco_d.registro_D505, self).__init__()
            self.REG = 'D505'
            self.nivel_h = 4
            self.pai = 'D500'
            self.ocorrencia = 'N'
            self.CST_COFINS = ''
            self.VL_ITEM = ''
            self.NAT_BC_CRED = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_PIS = ''
            self.VL_PIS = ''
            self.COD_CTA = ''
            self.fieldnames = ('REG', 'CST_COFINS', 'VL_ITEM', 'NAT_BC_CRED', 'VL_BC_COFINS',
                               'ALIQ_COFINS', 'VL_COFINS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_D510(TrackedAttributesClass):
        """
        REGISTRO D510: ITENS DO DOCUMENTO – NOTA FISCAL DE SERVIÇO DE
        COMUNICAÇÃO (CÓDIGO 21) E SERVIÇO DE TELECOMUNICAÇÃO (CÓDIGO 22).
        Este registro tem por objetivo informar os itens das Notas Fiscais de Serviços de Comunicação (código 21 da
        Tabela Documentos Fiscais do ICMS) e Notas Fiscais de Serviços de Telecomunicação (código 22 da Tabela Documentos
        Fiscais do ICMS). Não deve ser informado pelos adquirentes dos serviços
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D510, self).__init__()
            self.REG = 'D510'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D500'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_ITEM = ''
            self.COD_ITEM = ''
            self.COD_CLASS = ''
            self.QTD = ''
            self.UNID = ''
            self.VL_ITEM = ''
            self.VL_DESC = ''
            self.CST_ICMS = ''
            self.CFOP = ''
            self.VL_BC_ICMS = ''
            self.ALIQ_ICMS = ''
            self.VL_ICMS = ''
            self.VL_BC_ICMS_UF = ''
            self.VL_ICMS_UF = ''
            self.IND_REC = ''
            self.COD_PART = ''
            self.VL_PIS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D530(TrackedAttributesClass):
        """
        REGISTRO D530: TERMINAL FATURADO.
        Este registro tem por objetivo informar o terminal faturado de Nota Fiscal de Serviços de Comunicação (código 21
        da Tabela Documentos Fiscais do ICMS) e Nota Fiscal de Serviços de Telecomunicação (código 22 da Tabela Documentos
        Fiscais do ICMS).
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D530, self).__init__()
            self.REG = 'D530'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D500'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_SERV = ''
            self.DT_INI_SERV = ''
            self.DT_FIN_SERV = ''
            self.PER_FISCAL = ''
            self.COD_AREA = ''
            self.TERMINAL = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D590(TrackedAttributesClass):
        """
        REGISTRO D590: REGISTRO ANALÍTICO DO DOCUMENTO (CÓDIGO 21 E 22).
        Este registro tem por objetivo apresentar a escrituração das Notas Fiscais de Serviços de Comunicação (código 21
        da Tabela Documentos Fiscais do ICMS) e Notas Fiscais de Serviços de Telecomunicação (código 22 da Tabela
        Documentos Fiscais do ICMS), prestadas no registro D500 e totalizados pela combinação de CST, CFOP e Alíquota.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D590, self).__init__()
            self.REG = 'D590'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D500'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''
            self.CFOP = ''
            self.ALIQ_ICMS = ''
            self.VL_OPR = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.VL_BC_ICMS_UF = ''
            self.VL_ICMS_UF = ''
            self.VL_RED_BC = ''
            self.COD_OBS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D600(TrackedAttributesClass):
        """
        REGISTRO D600: CONSOLIDAÇÃO DA PRESTAÇÃO DE SERVIÇOS - NOTAS DE SERVIÇO DE COMUNICAÇÃO (CÓDIGO 21) E DE SERVIÇO DE TELECOMUNICAÇÃO
        (CÓDIGO 22).
        Este registro tem por objetivo consolidar as Notas Fiscais de Serviço de Comunicação (Código 21 da Tabela
        Documentos Fiscais do ICMS) e Notas Fiscais de Serviço de Telecomunicação (Código 22 da Tabela Documentos Fiscais
        do ICMS) para empresas não obrigadas ao Convênio ICMS 115/2003. Este registro deve ser fornecido apenas para
        prestações de saída.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D600, self).__init__()
            self.REG = 'D600'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'D001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''
            self.COD_MUN = ''
            self.SER = ''
            self.SUB = ''
            self.COD_CONS = ''
            self.QTD_CONS = ''
            self.DT_DOC = ''
            self.VL_DOC = ''
            self.VL_DESC = ''
            self.VL_SERV = ''
            self.VL_SERV_NT = ''
            self.VL_TERC = ''
            self.VL_DA = ''
            self.VL_BC_ICMS = ''
            self.ICMS = ''
            self.VL_PIS = ''
            self.VL_COFINS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D610(TrackedAttributesClass):
        """
        REGISTRO D610: ITENS DO DOCUMENTO CONSOLIDADO (CÓDIGO 21 E 22).
        Este registro tem por objetivo informar os itens das Notas Fiscais de Serviços de Comunicação (código 21 da
        Tabela Documentos Fiscais do ICMS) e Notas Fiscais de Serviços de Telecomunicação (código 22 da Tabela Documentos
        Fiscais do ICMS) consolidadas no registro D600.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D610, self).__init__()
            self.REG = 'D610'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D600'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_CLASS = ''
            self.COD_ITEM = ''
            self.QTD = ''
            self.UNID = ''
            self.VL_ITEM = ''
            self.VL_DESC = ''
            self.CST_ICMS = ''
            self.CFOP = ''
            self.ALIQ_ICMS = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.VL_BC_ICMS_UF = ''
            self.VL_ICMS_UF = ''
            self.VL_RED_BC = ''
            self.VL_PIS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D690(TrackedAttributesClass):
        """
        REGISTRO D690: REGISTRO ANALÍTICO DOS DOCUMENTOS (CÓDIGOS 21 e 22).
        Este registro tem por objetivo apresentar a escrituração da consolidação das Notas Fiscais de Serviços de
        Comunicação (código 21 da Tabela Documentos Fiscais do ICMS) e Notas Fiscais de Serviços de Telecomunicação
        (código 22 da Tabela Documentos Fiscais do ICMS), prestadas no registro D600 e totalizados pela combinação de CST,
        CFOP e Alíquota.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D690, self).__init__()
            self.REG = 'D690'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D600'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''
            self.CFOP = ''
            self.ALIQ_ICMS = ''
            self.VL_OPR = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.VL_BC_ICMS_UF = ''
            self.VL_ICMS_UF = ''
            self.VL_RED_BC = ''
            self.COD_OBS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D695(TrackedAttributesClass):
        """
        REGISTRO D695: CONSOLIDAÇÃO DA PRESTAÇÃO DE SERVIÇOS - NOTAS DE
        SERVIÇO DE COMUNICAÇÃO (CÓDIGO 21) E DE SERVIÇO DE TELECOMUNICAÇÃO
        (CÓDIGO 22) (EMPRESAS OBRIGADAS À ENTREGA DOS ARQUIVOS PREVISTOS NO
        CONVÊNIO ICMS 115/03).
        Este registro tem por objetivo apresentar a consolidação das Notas Fiscais de Serviços de Comunicação (código 21
        da Tabela Documentos Fiscais do ICMS) e Notas Fiscais de Serviços de Telecomunicação (código 22 da Tabela
        Documentos Fiscais do ICMS) pelas empresas obrigadas ao Convênio ICMS 115/2003.
        """

        _order = []

        def __init__(self):
            super(bloco_d.registro_D695, self).__init__()
            self.REG = 'D695'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'D001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_MOD = ''
            self.SER = ''
            self.NRO_ORD_INI = ''
            self.NRO_ORD_FIN = ''
            self.DT_DOC_INI = ''
            self.DT_DOC_FIN = ''
            self.NOM_MEST = ''
            self.CHV_COD_DIG = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D696(TrackedAttributesClass):
        """
        REGISTRO D696: REGISTRO ANALÍTICO DOS DOCUMENTOS (CÓDIGO 21 E 22).
        Este registro tem o objetivo de resumir o tratamento tributário aplicado aos documentos fiscais de serviços de
        comunicação e telecomunicação, especificados no Registro D695, totalizados pelo CST, CFOP e Alíquota.
        Este registro representa a escrituração da consolidação das Notas Fiscais de Serviços de Comunicação (código 21
        da Tabela Documentos Fiscais do ICMS) e Notas Fiscais de Serviços de Telecomunicação (código 22 da Tabela
        Documentos Fiscais do ICMS) prestadas no registro D695 e totalizadas pela combinação de CST, CFOP e Alíquota, em
        conformidade com os documentos constantes dos arquivos referentes ao Convênio ICMS no 115/03.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D696, self).__init__()
            self.REG = 'D696'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'D695'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CST_ICMS = ''
            self.CFOP = ''
            self.ALIQ_ICMS = ''
            self.VL_OPR = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.VL_BC_ICMS_UF = ''
            self.VL_ICMS_UF = ''
            self.VL_RED_BC = ''
            self.COD_OBS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D697(TrackedAttributesClass):
        """
        REGISTRO D697: REGISTRO DE INFORMAÇÕES DE OUTRAS UFs, RELATIVAMENTE
        AOS SERVIÇOS “NÃO-MEDIDOS” DE TELEVISÃO POR ASSINATURA VIA SATÉLITE.
        Este registro deve ser apresentado para a UF do prestador de serviços pelas empresas do setor, para informar os
        valores da base de cálculo e o valor de ICMS, totalizados por UF dos tomadores de serviços, conforme documentos
        emitidos e constantes dos arquivos do Convênio ICMS no 115/03.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D697, self).__init__()
            self.REG = 'D697'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'D696'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.UF = ''
            self.VL_BC_ICMS = ''
            self.VL_ICMS = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_D990(TrackedAttributesClass):
        """
        REGISTRO D990: ENCERRAMENTO DO BLOCO D.
        Este registro tem por objetivo identificar o encerramento do bloco D e informar a quantidade de linhas (registros)
        existentes no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_d.registro_D990, self).__init__()
            self.REG = 'D990'  # Texto fixo contendo
            self.nivel_h = 1  #nível
            self.pai = '0000'
            self.ocorrencia = '1'  #ocorrência por arquivo
            self.QTD_LIN_D = ''
            self.fieldnames = ('REG', 'QTD_LIN_D')
            self.formato = self.get_formato()
