#!/usr/bin/python
# -*- coding: utf-8 -*-
from ..utils import *


class bloco_k(TrackedAttributesClass):
    """
    BLOCO K: CONTROLE DA PRODUÇÃO E DO ESTOQUE
    Este bloco se destina a prestar informações mensais da produção e respectivo consumo de insumos,
    bem como do estoque escriturado, relativos aos estabelecimentos industriais ou a eles
    equiparados pela legislação federal e pelos atacadistas, podendo, a critério do Fisco, ser
    exigido de estabelecimento de contribuintes de outros setores (conforme § 4o do art. 63 do
    Convênio s/número, de 1970).
    """

    class registro_K001(TrackedAttributesClass):
        """
        REGISTRO K001: ABERTURA DO BLOCO K
        Este registro deve ser gerado para abertura do bloco K,
        indicando se há registros de informações no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_k.registro_K001, self).__init__()
            self.REG = 'K001'
            self.nivel_h = 1
            self.pai = '0000'
            self.ocorrencia = '1'
            self.IND_MOV = '1'
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_K100(TrackedAttributesClass):
        """
        REGISTRO K100: PERÍODO DE APURAÇÃO DO ICMS/IPI
        Este registro tem o objetivo de informar o período de apuração do ICMS ou do IPI,
        prevalecendo os períodos mais curtos. Contribuintes com mais de um período de apuração no
        mês declaram um registro K100 para cada período no mesmo arquivo. Não podem ser informados
        dois ou mais registros com os mesmos campos DT_INI e DT_FIN.
        """
        _order = []

        def __init__(self):
            super(bloco_k.registro_K100, self).__init__()
            self.REG = 'K100'
            self.nivel_h = 2
            self.pai = 'K001'
            self.ocorrencia = 'N'
            self.DT_INI = ''
            self.DT_FIN = ''
            self.fieldnames = ('REG', 'DT_INI', 'DT_FIN')
            self.formato = self.get_formato()

    class registro_K200(TrackedAttributesClass):
        """
        REGISTRO K200: ESTOQUE ESCRITURADO
        Este registro tem o objetivo de informar o estoque final escriturado do período de apuração
        informado no Registro K100, por tipo de estoque e por participante, nos casos em que couber,
        das mercadorias de tipos 00 – Mercadoria para revenda, 01 – Matéria-Prima, 02 - Embalagem,
        03 – Produtos em Processo, 04 – Produto Acabado, 05 – Subproduto e 10 – Outros Insumos –
        campo TIPO_ITEM do Registro 0200.
        A unidade de medida é, obrigatoriamente, a de controle de estoque constante no campo 06 do
        registro 0200 – UNID_INV.
        A chave deste registro são os campos: DT_EST, COD_ITEM, IND_EST e COD_PART (este, quando
        'houver).
        """
        _order = []

        def __init__(self):
            super(bloco_k.registro_K200, self).__init__()
            self.REG = 'K200'
            self.nivel_h = 3
            self.pai = 'k100'
            self.ocorrencia = 'N'
            self.DT_EST = ''
            self.COD_ITEM = ''
            self.QTD = ''
            self.IND_EST = ''
            self.COD_PART = ''
            self.fieldnames = ('REG', 'DT_EST', 'COD_ITEM', 'QTD', 'IND_EST', 'COD_PART')
            self.formato = self.get_formato()

    class registro_K230(TrackedAttributesClass):
        """
        REGISTRO K230: ITENS PRODUZIDOS
        Este registro tem o objetivo de informar a produção acabada de produto em processo
        (tipo 03 – campo TIPO_ITEM do registro 0200) e produto acabado (tipo 04 – campo TIPO_ITEM do
        registro 0200).
        Deverá existir mesmo que a quantidade de produção acabada seja igual a zero, nas situações
        em que exista o consumo de item componente/insumo no registro filho K235. Nessa situação a
        produção ficou em elaboração. Essa produção em elaboração não é quantificada, uma vez que a
        matéria não é mais um insumo e nem é ainda um produto resultante. A unidade de medida é,
        obrigatoriamente, a de controle de estoque constante no campo 06 do registro 0200: UNID_INV.
        Quando houver identificação da ordem de produção, a chave deste registro são os campos:
        COD_DOC_OP e COD_ITEM.
        Nos casos em que a ordem de produção não for identificada, o campo chave passa a ser COD_ITEM.
        """

        _order = []

        def __init__(self):
            super(bloco_k.registro_K230, self).__init__()
            self.REG = 'K230'
            self.nivel_h = 3
            self.pai = 'k200'
            self.ocorrencia = 'N'
            self.DT_INI_OP = ''
            self.DT_FIN_OP = ''
            self.COD_DOC_OP = ''
            self.COD_ITEM = ''
            self.QTD_ENC = ''
            self.fieldnames = ('REG', 'DT_INI_OP', 'DT_FIN_OP', 'COD_DOC_OP', 'COD_ITEM', 'QTD_ENC')

    class registro_K235(TrackedAttributesClass):
        """
        REGISTRO K235: INSUMOS CONSUMIDOS
        Este registro tem o objetivo de informar o consumo de mercadoria no processo produtivo,
        vinculado ao produto resultante informado no campo COD_ITEM do Registro K230 – Itens
        Produzidos.
        A unidade de medida é, obrigatoriamente, a de controle de estoque constante no campo 06 do
        registro 0200:
        UNID_INV.
        A chave deste registro são os campos DT_SAÍDA e COD_ITEM.
        """

        _order = []

        def __init__(self):
            super(bloco_k.registro_K235, self).__init__()
            self.REG = 'K235'
            self.nivel_h = 4
            self.pai = 'K230'
            self.ocorrencia = 'N'
            self.DT_SAIDA = ''
            self.COD_ITEM = ''
            self.QTD = ''
            self.COD_INS_SUBST = ''
            self.fieldnames = ('REG', 'DT_SAIDA', 'COD_ITEM', 'QTD', 'COD_INS_SUBST')
            self.formato = self.get_formato()

    class registro_K990(TrackedAttributesClass):
        """
        REGISTRO K990: ENCERRAMENTO DO BLOCO K
        Este registro destina-se a identificar o encerramento do bloco K e a informar a quantidade
        de linhas (registros)
        existentes no bloco.
        """

        _order = []

        def __init__(self):
            super(bloco_k.registro_K990, self).__init__()
            self.REG = 'K990'
            self.nivel_h = 1
            self.pai = '0000'
            self.ocorrencia = '1'
            self.QTD_LIN_K = ''
            self.fieldnames = ('REG', 'QTD_LIN_K')
            self.formato = self.get_formato()








